Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(533)

Unified Diff: chrome/browser/ui/views/harmony/layout_delegate_unittest.cc

Issue 2758323002: Broke out layout metric information from ViewsDelegate to LayoutProvider (Closed)
Patch Set: Fix warning which causes one of the bots to fail Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/harmony/layout_delegate_unittest.cc
diff --git a/chrome/browser/ui/views/harmony/layout_delegate_unittest.cc b/chrome/browser/ui/views/harmony/layout_delegate_unittest.cc
index 89306aac3b2576ba3c3dd3b7d82170cf00053438..f1fb38da2de8dbf83436cfb47089966c895e3831 100644
--- a/chrome/browser/ui/views/harmony/layout_delegate_unittest.cc
+++ b/chrome/browser/ui/views/harmony/layout_delegate_unittest.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chrome/browser/ui/views/chrome_views_delegate.h"
+#include "chrome/browser/ui/views/harmony/chrome_layout_delegate.h"
#include "chrome/browser/ui/views/harmony/chrome_typography.h"
#include "testing/gtest/include/gtest/gtest.h"
#include "ui/base/default_style.h"
@@ -192,8 +192,9 @@ TEST(LayoutDelegateTest, FontSizeRelativeToBase) {
constexpr int kStyle = views::style::STYLE_PRIMARY;
- // Typography described in chrome_typography.h requires a ChromeViewsDelegate.
- ChromeViewsDelegate views_delegate;
+ // Typography described in chrome_typography.h requires a
+ // ChromeLayoutDelegate.
+ ChromeLayoutDelegate layout_delegate;
// Legacy code measures everything relative to a default-constructed FontList.
// On Mac, subtract one since that is 13pt instead of 12pt.

Powered by Google App Engine
This is Rietveld 408576698